@@ -4,15 +4,17 @@ import base64
 import os
 import posixpath
 import re
+import subprocess
 
 from itertools import takewhile
 
 from django.contrib.staticfiles.storage import staticfiles_storage
 from django.utils.encoding import smart_bytes, force_text
+from django.utils.six import string_types
 
 from pipeline.conf import settings
-from pipeline.utils import to_class, relpath
 from pipeline.exceptions import CompressorError
+from pipeline.utils import to_class, relpath, set_std_streams_blocking
 
 URL_DETECTOR = r"""url\((['"]){0,1}\s*(.*?)["']{0,1}\)"""
 URL_REPLACER = r"""url\(__EMBED__(.+?)(\?\d+)?\)"""
@@ -47,11 +49,11 @@ class Compressor(object):
 
     @property
     def js_compressor(self):
-        return to_class(settings.PIPELINE_JS_COMPRESSOR)
+        return to_class(settings.JS_COMPRESSOR)
 
     @property
     def css_compressor(self):
-        return to_class(settings.PIPELINE_CSS_COMPRESSOR)
+        return to_class(settings.CSS_COMPRESSOR)
 
     def compress_js(self, paths, templates=None, **kwargs):
         """Concatenate and compress JS files"""
@@ -59,7 +61,7 @@ class Compressor(object):
         if templates:
             js = js + self.compile_templates(templates)
 
-        if not settings.PIPELINE_DISABLE_WRAPPER:
+        if not settings.DISABLE_WRAPPER:
             js = "(function() {\n%s\n}).call(this);" % js
 
         compressor = self.js_compressor
@@ -85,7 +87,7 @@ class Compressor(object):
         compiled = []
         if not paths:
             return ''
-        namespace = settings.PIPELINE_TEMPLATE_NAMESPACE
+        namespace = settings.TEMPLATE_NAMESPACE
         base_path = self.base_path(paths)
         for path in paths:
             contents = self.read_text(path)
@@ -95,10 +97,10 @@ class Compressor(object):
             compiled.append("%s['%s'] = %s('%s');\n" % (
                 namespace,
                 name,
-                settings.PIPELINE_TEMPLATE_FUNC,
+                settings.TEMPLATE_FUNC,
                 contents
             ))
-        compiler = TEMPLATE_FUNC if settings.PIPELINE_TEMPLATE_FUNC == DEFAULT_TEMPLATE_FUNC else ""
+        compiler = TEMPLATE_FUNC if settings.TEMPLATE_FUNC == DEFAULT_TEMPLATE_FUNC else ""
         return "\n".join([
             "%(namespace)s = %(namespace)s || {};" % {'namespace': namespace},
             compiler,
@@ -118,9 +120,9 @@ class Compressor(object):
         if path == base:
             base = os.path.dirname(path)
         name = re.sub(r"^%s[\/\\]?(.*)%s$" % (
-            re.escape(base), re.escape(settings.PIPELINE_TEMPLATE_EXT)
+            re.escape(base), re.escape(settings.TEMPLATE_EXT)
         ), r"\1", path)
-        return re.sub(r"[\/\\]", settings.PIPELINE_TEMPLATE_SEPARATOR, name)
+        return re.sub(r"[\/\\]", settings.TEMPLATE_SEPARATOR, name)
 
     def concatenate_and_rewrite(self, paths, output_filename, variant=None):
         """Concatenate together files and rewrite urls"""
@@ -163,11 +165,11 @@ class Compressor(object):
         font = ext in FONT_EXTS
         if not variant:
             return False
-        if not (re.search(settings.PIPELINE_EMBED_PATH, path.replace('\\', '/')) and self.storage.exists(path)):
+        if not (re.search(settings.EMBED_PATH, path.replace('\\', '/')) and self.storage.exists(path)):
             return False
         if ext not in EMBED_EXTS:
             return False
-        if not (font or len(self.encoded_content(path)) < settings.PIPELINE_EMBED_MAX_IMAGE_SIZE):
+        if not (font or len(self.encoded_content(path)) < settings.EMBED_MAX_IMAGE_SIZE):
             return False
         return True
 
@@ -234,12 +236,19 @@ class CompressorBase(object):
 
 class SubProcessCompressor(CompressorBase):
     def execute_command(self, command, content):
-        import subprocess
-        pipe = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE,
+        argument_list = []
+        for flattening_arg in command:
+            if isinstance(flattening_arg, string_types):
+                argument_list.append(flattening_arg)
+            else:
+                argument_list.extend(flattening_arg)
+
+        pipe = subprocess.Popen(argument_list, stdout=subprocess.PIPE,
                                 stdin=subprocess.PIPE, stderr=subprocess.PIPE)
         if content:
             content = smart_bytes(content)
         stdout, stderr = pipe.communicate(content)
+        set_std_streams_blocking()
         if stderr.strip() and pipe.returncode != 0:
             raise CompressorError(stderr)
         elif self.verbose:
