@@ -24,10 +24,10 @@ class PipelineFinder(BaseStorageFinder):
 class ManifestFinder(BaseFinder):
     def find(self, path, all=False):
         """
-        Looks for files in PIPELINE_CSS and PIPELINE_JS
+        Looks for files in PIPELINE.STYLESHEETS and PIPELINE.JAVASCRIPT
         """
         matches = []
-        for elem in chain(settings.PIPELINE_CSS.values(), settings.PIPELINE_JS.values()):
+        for elem in chain(settings.STYLESHEETS.values(), settings.JAVASCRIPT.values()):
             if elem['output_filename'] == path:
                 match = safe_join(settings.PIPELINE_ROOT, path)
                 if not all:
